@@ -1,11 +1,35 @@
 from typing import Callable, Union
-from time import time
+from time import time, sleep
+from datetime import datetime
 from threading import Thread
 from multiprocessing import Process
 from functools import wraps
-from time import sleep
 from json import load as json_load
 from yaml import safe_load as yaml_load
+from math import sqrt
+
+def get_time() -> dict:
+    """
+    Info:
+        Returns the time in different ways via a dictionary/
+
+    Usage;
+        get_time()
+
+    Returns:
+        dict
+    """
+    time = datetime.now()
+    return {
+        'millisecond': time.microsecond, 
+        'second': time.second, 
+        'minute': time.minute, 
+        'hour': time.hour, 
+        'day': time.day, 
+        'month': time.month, 
+        'year': time.year, 
+        'date': time.strftime("%m/%d/%Y %H:%M")
+    }
 
 def replace_str_index(text: str, index: int, replacement: Union[str, int]) -> str:
     """
@@ -63,6 +87,28 @@ def is_prime(number: int) -> bool:
 
     return True
 
+def prime_factors(number: int) -> list:
+    """
+    Info:
+        Generates a list of prime numbers that are factors of the given number.
+
+    Paramaters:
+        number: int - The number to get prime factors of.
+
+    Usage:
+        prime_facotrs(100)
+
+    Returns:
+        list
+    """
+    factors = []
+    if is_prime(number) or number < 3:
+        return factors
+    for i in range(2, number):
+        if number % i == 0 and is_prime(i):
+            factors.append(i)
+    return factors
+    
 def convert_list_items(old_list: list, type: type):
     """
     Info:
@@ -527,10 +573,10 @@ def load_json(file_name: str):
         Loads the given json file and returns its value.
 
     Paramaters:
-        file_name: str - File name, ending with .json
+        file_name: str - File name, ending with .json.
 
     Usgae:
-        load_json('file.json')
+        load_json(file)
 
     Returns:
         dict
@@ -539,23 +585,73 @@ def load_json(file_name: str):
         my_file = json_load(my_file_raw)
         return my_file
 
-
-
-
 def load_yaml(file_name: str):
     """
     Info:
         Loads the given yaml file and returns its value.
 
     Paramaters:
-        file_name: str - File name, ending with .yaml or .yml
+        file_name: str - File name, ending with .yaml or .yml.
 
     Usgae:
-        load_yaml('file.yaml')
+        load_yaml(file)
 
     Returns:
         dict
     """
     with open(file_name, 'r') as my_file_raw:
         my_file = yaml_load(my_file_raw)
-        return my_file
\ No newline at end of file
+        return my_file
+
+def square_root(number: int) -> int:
+    """
+    Info:
+        Returns the square root of a number.
+
+    Paramaters:
+        number: int - The number to get the square root of.
+
+    Usage:
+        square_root(number)
+
+    Returns:
+        int
+    """
+    return sqrt(number)
+
+def true_or_false() -> dict:
+    """
+    Info:
+        Returns a dict that contains two list, containing words if its true/false acceptance.
+    
+    Usage:
+        true_or_false()
+
+    Returns:
+        dict
+    """
+    return {
+        'true': [
+            'true',
+            'y',
+            'ye',
+            'yes',
+            'yeah',
+            'yup',
+            'accept',
+            'confirm',
+            'mhmm',
+            'ok',
+            'sure',
+            'alright'
+        ], 
+        'false': [
+            'false',
+            'no',
+            'nah',
+            'nope',
+            'never',
+            'n',
+            'deny',
+            'negative'
+        ]}
